@@ -65,7 +65,6 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "hotplug.h"
 #include "readerfactory.h"
 #include "configfile.h"
-#include "powermgt_generic.h"
 #include "utils.h"
 #include "eventhandler.h"
 
@@ -91,8 +90,8 @@ char Add_Interface_In_Name = TRUE;
 static void at_exit(void);
 static void clean_temp_files(void);
 static void signal_trap(int);
-static void print_version (void);
-static void print_usage (char const * const);
+static void print_version(void);
+static void print_usage(char const * const);
 
 /**
  * @brief The Server's Message Queue Listener function.
@@ -372,7 +371,7 @@ int main(int argc, char **argv)
 				return EXIT_SUCCESS;
 
 			case 'a':
-				(void)DebugLogSetCategory(DEBUG_CATEGORY_APDU);
+				DebugLogSetCategory(DEBUG_CATEGORY_APDU);
 				break;
 
 			case 'H':
@@ -749,11 +748,6 @@ int main(int argc, char **argv)
 	RFWaitForReaderInit();
 #endif
 
-	/*
-	 * Set up the power management callback routine
-	 */
-	(void)PMRegisterForPowerEvents();
-
 	/* initialisation succeeded */
 	if (pipefd[1] >= 0)
 	{
@@ -827,7 +821,7 @@ static void signal_trap(int sig)
 		Log2(PCSC_LOG_ERROR, "write failed: %s", strerror(errno));
 }
 
-static void print_version (void)
+static void print_version(void)
 {
 	printf("%s version %s.\n",  PACKAGE, VERSION);
 	printf("Copyright (C) 1999-2002 by David Corcoran <corcoran@musclecard.com>.\n");
@@ -838,7 +832,7 @@ static void print_version (void)
 	printf ("Enabled features:%s\n", PCSCLITE_FEATURES);
 }
 
-static void print_usage (char const * const progname)
+static void print_usage(char const * const progname)
 {
 	printf("Usage: %s options\n", progname);
 	printf("Options:\n");
