@@ -49,6 +49,9 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <errno.h>
 #include <fcntl.h>
 #include <pthread.h>
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
 
 #include "misc.h"
 #include "pcscd.h"
@@ -612,78 +615,72 @@ LONG RFRemoveReader(const char *readerName, int port)
 
 LONG removeReader(READER_CONTEXT * sContext)
 {
-	LONG rv;
+	/* Try to destroy the thread */
+	if (sContext -> pthThread)
+		EHDestroyEventHandler(sContext);
 
+	if ((NULL == sContext->pMutex) || (NULL == sContext->pFeeds))
 	{
-		/* Try to destroy the thread */
-		if (sContext -> pthThread)
-			(void)EHDestroyEventHandler(sContext);
-
-		if ((NULL == sContext->pMutex) || (NULL == sContext->pFeeds))
-		{
-			Log1(PCSC_LOG_ERROR,
+		Log1(PCSC_LOG_ERROR,
 				"Trying to remove an already removed driver");
-			return SCARD_E_INVALID_VALUE;
-		}
+		return SCARD_E_INVALID_VALUE;
+	}
 
-		rv = RFUnInitializeReader(sContext);
-		if (rv != SCARD_S_SUCCESS)
-			return rv;
+	RFUnInitializeReader(sContext);
 
-		*sContext->pMutex -= 1;
+	*sContext->pMutex -= 1;
 
-		/* free shared resources when the last slot is closed */
-		if (0 == *sContext->pMutex)
-		{
-			(void)pthread_mutex_destroy(sContext->mMutex);
-			free(sContext->mMutex);
-			sContext->mMutex = NULL;
-			free(sContext->library);
-			free(sContext->device);
-			free(sContext->pMutex);
-			sContext->pMutex = NULL;
-		}
+	/* free shared resources when the last slot is closed */
+	if (0 == *sContext->pMutex)
+	{
+		(void)pthread_mutex_destroy(sContext->mMutex);
+		free(sContext->mMutex);
+		sContext->mMutex = NULL;
+		free(sContext->library);
+		free(sContext->device);
+		free(sContext->pMutex);
+		sContext->pMutex = NULL;
+	}
 
-		*sContext->pFeeds -= 1;
+	*sContext->pFeeds -= 1;
 
-		/* Added by Dave to free the pFeeds variable */
-		if (*sContext->pFeeds == 0)
-		{
-			free(sContext->pFeeds);
-			sContext->pFeeds = NULL;
-		}
+	/* Added by Dave to free the pFeeds variable */
+	if (*sContext->pFeeds == 0)
+	{
+		free(sContext->pFeeds);
+		sContext->pFeeds = NULL;
+	}
 
-		(void)pthread_mutex_destroy(&sContext->powerState_lock);
-		sContext->version = 0;
-		sContext->port = 0;
-		sContext->contexts = 0;
-		sContext->slot = 0;
-		sContext->hLockId = 0;
-		sContext->LockCount = 0;
-		sContext->vHandle = NULL;
+	(void)pthread_mutex_destroy(&sContext->powerState_lock);
+	sContext->version = 0;
+	sContext->port = 0;
+	sContext->contexts = 0;
+	sContext->slot = 0;
+	sContext->hLockId = 0;
+	sContext->LockCount = 0;
+	sContext->vHandle = NULL;
 
-		(void)pthread_mutex_lock(&sContext->handlesList_lock);
-		while (list_size(&sContext->handlesList) != 0)
-		{
-			int lrv;
-			RDR_CLIHANDLES *currentHandle;
+	(void)pthread_mutex_lock(&sContext->handlesList_lock);
+	while (list_size(&sContext->handlesList) != 0)
+	{
+		int lrv;
+		RDR_CLIHANDLES *currentHandle;
 
-			currentHandle = list_get_at(&sContext->handlesList, 0);
-			lrv = list_delete_at(&sContext->handlesList, 0);
-			if (lrv < 0)
-				Log2(PCSC_LOG_CRITICAL,
+		currentHandle = list_get_at(&sContext->handlesList, 0);
+		lrv = list_delete_at(&sContext->handlesList, 0);
+		if (lrv < 0)
+			Log2(PCSC_LOG_CRITICAL,
 					"list_delete_at failed with return value: %d", lrv);
 
-			free(currentHandle);
-		}
-		(void)pthread_mutex_unlock(&sContext->handlesList_lock);
-		(void)pthread_mutex_destroy(&sContext->handlesList_lock);
-		list_destroy(&sContext->handlesList);
-		dwNumReadersContexts -= 1;
-
-		/* signal an event to clients */
-		(void)EHSignalEventToClients();
+		free(currentHandle);
 	}
+	(void)pthread_mutex_unlock(&sContext->handlesList_lock);
+	(void)pthread_mutex_destroy(&sContext->handlesList_lock);
+	list_destroy(&sContext->handlesList);
+	dwNumReadersContexts -= 1;
+
+	/* signal an event to clients */
+	EHSignalEventToClients();
 
 	return SCARD_S_SUCCESS;
 }
@@ -1026,15 +1023,25 @@ LONG RFUnlockSharing(SCARDHANDLE hCard, READER_CONTEXT * rContext)
 	rv = RFCheckSharing(hCard, rContext);
 	if (SCARD_S_SUCCESS == rv)
 	{
-		if (rContext->LockCount > 0)
+		if (PCSCLITE_SHARING_EXCLUSIVE_CONTEXT == rContext->contexts)
 		{
-			rContext->LockCount -= 1;
-			if (0 == rContext->LockCount)
-				rContext->hLockId = 0;
+			if (rContext->LockCount > 1)
+				rContext->LockCount -= 1;
+			else
+				rv = SCARD_E_NOT_TRANSACTED;
 		}
 		else
-			/* rContext->LockCount == 0 */
-			rv = SCARD_E_NOT_TRANSACTED;
+		{
+			if (rContext->LockCount > 0)
+			{
+				rContext->LockCount -= 1;
+				if (0 == rContext->LockCount)
+					rContext->hLockId = 0;
+			}
+			else
+				/* rContext->LockCount == 0 */
+				rv = SCARD_E_NOT_TRANSACTED;
+		}
 	}
 	(void)pthread_mutex_unlock(&LockMutex);
 
@@ -1111,7 +1118,7 @@ LONG RFInitializeReader(READER_CONTEXT * rContext)
 	return SCARD_S_SUCCESS;
 }
 
-LONG RFUnInitializeReader(READER_CONTEXT * rContext)
+void RFUnInitializeReader(READER_CONTEXT * rContext)
 {
 	Log2(PCSC_LOG_INFO, "Attempting shutdown of %s.",
 		rContext->readerState->readerName);
@@ -1136,7 +1143,7 @@ LONG RFUnInitializeReader(READER_CONTEXT * rContext)
 	rContext->readerState->cardAtrLength = READER_NOT_INITIALIZED;
 	rContext->readerState->cardProtocol = SCARD_PROTOCOL_UNDEFINED;
 
-	return SCARD_S_SUCCESS;
+	return;
 }
 
 SCARDHANDLE RFCreateReaderHandle(READER_CONTEXT * rContext)
@@ -1169,12 +1176,6 @@ SCARDHANDLE RFCreateReaderHandle(READER_CONTEXT * rContext)
 	return randHandle;
 }
 
-LONG RFDestroyReaderHandle(/*@unused@*/ SCARDHANDLE hCard)
-{
-	(void)hCard;
-	return SCARD_S_SUCCESS;
-}
-
 LONG RFAddReaderHandle(READER_CONTEXT * rContext, SCARDHANDLE hCard)
 {
 	int listLength, lrv;
@@ -1247,7 +1248,7 @@ end:
 	return rv;
 }
 
-LONG RFSetReaderEventState(READER_CONTEXT * rContext, DWORD dwEvent)
+void RFSetReaderEventState(READER_CONTEXT * rContext, DWORD dwEvent)
 {
 	/* Set all the handles for that reader to the event */
 	int list_index, listSize;
@@ -1277,7 +1278,7 @@ LONG RFSetReaderEventState(READER_CONTEXT * rContext, DWORD dwEvent)
 		rContext->LockCount = 0;
 	}
 
-	return SCARD_S_SUCCESS;
+	return;
 }
 
 LONG RFCheckReaderEventState(READER_CONTEXT * rContext, SCARDHANDLE hCard)
